<?php

// Register Newsletter Form Widget
if(class_exists('Newsletter')) {
    $news_forms = array_filter( (array) get_option( 'newsletter_forms', array() ) );
    $news_forms_list = array(
        'default' => esc_html__( 'Default Form', 'frontline' )
    );
    if ( $news_forms )
    {
        $index = 1;
        foreach ( $news_forms as $key => $form )
        {
            $news_forms_list[$key] = sprintf( esc_html__( 'form_%s', 'frontline' ), $index );
            $index ++;
        }
    }
    etc_add_custom_widget(
        array(
            'name' => 'cms_newsletter',
            'title' => esc_html__('Newsletter Forms', 'frontline'),
            'icon' => 'eicon-form-horizontal',
            'categories' => array(Elementor_Theme_Core::ETC_CATEGORY_NAME),
            'scripts' => array(
                'cms-newsletter-widget-js',
            ),
            'params' => array(
                'sections' => array(
                    array(
                        'name' => 'source_section',
                        'label' => esc_html__('Content Settings', 'frontline'),
                        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                        'controls' => array(
                            array(
                                'name' => 'description_text',
                                'label' => esc_html__('Description', 'frontline' ),
                                'type' => \Elementor\Controls_Manager::TEXTAREA,
                                'default' => '',
                                'placeholder' => esc_html__('Enter your description', 'frontline' ),
                                'rows' => 6,
                                'show_label' => false,
                            ),
                            array(
                                'name' => 'newsletter_id',
                                'label' => esc_html__('Select Form', 'frontline'),
                                'type' => \Elementor\Controls_Manager::SELECT,
                                'options' => $news_forms_list,
                                'default' => 'default',
                            ),
                            array(
                                'name' => 'form_style',
                                'label' => esc_html__('Form Style', 'frontline'),
                                'type' => \Elementor\Controls_Manager::SELECT,
                                'options' => [
                                    'default' => esc_html__('Default', 'frontline' ),
                                    'minimal' => esc_html__('Minimal', 'frontline' ),
                                ],
                                'default' => 'default',
                            ),
                        ),
                    ),
                    array(
                        'name' => 'section_style_form',
                        'label' => esc_html__('Form Style', 'frontline' ),
                        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                        'controls' => array(
                            array(
                                'name' => 'form_background',
                                'type' => \Elementor\Group_Control_Background::get_type(),
                                'control_type' => 'group',
                                'types'             => [ 'classic' , 'gradient' ],
                                'selector' => '{{WRAPPER}} .cms-newsletter-form',
                            ),
                            array(
                                'name' => 'description_color',
                                'label' => esc_html__('Description Color', 'frontline' ),
                                'type' => \Elementor\Controls_Manager::COLOR,
                                'selectors' => [
                                    '{{WRAPPER}} .cms-newsletter-form .form-description' => 'color: {{VALUE}};',
                                ],
                            ),
                            array(
                                'name' => 'description_typography',
                                'label' => esc_html__('Description Typo', 'frontline' ),
                                'type' => \Elementor\Group_Control_Typography::get_type(),
                                'control_type' => 'group',
                                'selector' => '{{WRAPPER}} .cms-newsletter-form .form-description',
                            ),
                        ),
                    ),
                    array(
                        'name' => 'section_style_button',
                        'label' => esc_html__('Button Style', 'frontline' ),
                        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                        'controls' => array(
                            array(
                                'name' => 'button_style_tabs',
                                'control_type' => 'tab',
                                'tabs' => array(
                                    array(
                                        'name' => 'button_style_normal',
                                        'label' => esc_html__('Normal', 'frontline'),
                                        'controls' => array(
                                            array(
                                                'name' => 'button_color',
                                                'label' => esc_html__('Text Color', 'frontline'),
                                                'type' => \Elementor\Controls_Manager::COLOR,
                                                'selectors' => [
                                                    '{{WRAPPER}} .tnp-subscription input.tnp-submit' => 'color: {{VALUE}};'
                                                ]
                                            ),
                                            array(
                                                'name' => 'button_background',
                                                'type' => \Elementor\Group_Control_Background::get_type(),
                                                'control_type' => 'group',
                                                'types'             => [ 'classic' , 'gradient' ],
                                                'selector' => '{{WRAPPER}} .tnp-subscription input.tnp-submit, {{WRAPPER}} .tnp-subscription .tnp-field-button:after',
                                            ),

                                        )
                                    ),
                                    array(
                                        'name' => 'button_style_hover',
                                        'label' => esc_html__('Hover', 'frontline'),
                                        'controls' => array(
                                            array(
                                                'name' => 'button_color_hover',
                                                'label' => esc_html__('Text Color', 'frontline'),
                                                'type' => \Elementor\Controls_Manager::COLOR,
                                                'selectors' => [
                                                    '{{WRAPPER}} .tnp-subscription input.tnp-submit:hover' => 'color: {{VALUE}};'
                                                ]
                                            ),
                                            array(
                                                'name' => 'button_background_hover',
                                                'type' => \Elementor\Group_Control_Background::get_type(),
                                                'control_type' => 'group',
                                                'types'             => [ 'classic' , 'gradient' ],
                                                'selector' => '{{WRAPPER}} .tnp-subscription input.tnp-submit:hover',
                                            ),
                                        )
                                    ),
                                )
                            ),
                        ),
                    ),
                ),
            ),
        ),
        get_template_directory() . '/elementor/core/widgets/'
    );
}