<?php
/**
 * Template part for displaying posts in loop
 *
 * @package Frontline
 */
$post_tags_on = frontline_get_opt( 'post_tags_on', true );
$post_author_on = frontline_get_opt('post_author_on', true);
$post_social_share_on = frontline_get_opt( 'post_social_share_on', false );
$post_view_on = frontline_get_opt( 'post_view_on', false );
$post_feature_image_on = frontline_get_opt( 'post_feature_image_on', true );
$post_categories_on = frontline_get_opt( 'post_categories_on', true );
$post_date_on = frontline_get_opt('post_date_on', true);
$post_comments_on = frontline_get_opt('post_comments_on', true);
?>
<article id="post-<?php the_ID(); ?>" <?php post_class('single-hentry'); ?>>
    <?php if (has_post_format('gallery')) : ?>
        <div class="entry-featured">
            <?php
            $light_box = frontline_get_post_format_value('post-gallery-lightbox', '0');
            $gallery_list = explode(',', frontline_get_post_format_value('post-gallery-images', ''));
            wp_enqueue_script( 'owl-carousel' );
            wp_enqueue_script( 'frontline-carousel' );
            ?>
            <div class="cms-carousel owl-carousel featured-active <?php if($light_box) {echo 'images-light-box';} ?>" data-item-xs="1" data-item-sm="1" data-item-md="1" data-item-lg="1" data-item-xl="1" data-item-xxl="1" data-margin="30" data-loop="true" data-autoplay="false" data-autoplaytimeout="5000" data-smartspeed="250" data-center="false" data-arrows="true" data-bullets="false" data-stagepadding="0" data-stagepaddingsm="0" data-rtl="false">
                <?php
                foreach ($gallery_list as $img_id):
                    ?>
                    <div class="cms-carousel-item">
                        <a class="light-box" href="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'full'));?>"><img src="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'large'));?>" alt="<?php echo esc_attr(get_post_meta( $img_id, '_wp_attachment_image_alt', true )) ?>"></a>
                    </div>
                    <?php
                endforeach;
                ?>
            </div>
            <h2 class="entry-title">
                <a href="<?php echo esc_url( get_permalink()); ?>">
                    <?php if(is_sticky()) { ?>
                        <i class="fa fa-thumb-tack"></i>
                    <?php } ?>
                    <?php the_title(); ?>
                </a>
            </h2>
        </div>
    <?php elseif (has_post_format('quote')) : ?>
        <div class="entry-featured">
            <?php
                $quote_text = frontline_get_post_format_value('post-quote-cite', '');
                echo esc_attr($quote_text);
            ?>
        </div>
    <?php elseif (has_post_format('link')) : ?>
        <div class="entry-featured">
            <?php
                $link_pf = frontline_get_post_format_value('post-link-url', '#');
                echo esc_url($link_pf);
            ?>
        </div>
    <?php elseif (has_post_format('video')) : ?>
        <div class="entry-featured">
            <div class="entry-video featured-active">
                <?php
                $video_url = frontline_get_post_format_value('post-video-url', '#');
                $video_file = frontline_get_post_format_value('post-video-file', '');
                $video_html = frontline_get_post_format_value('post-video-html', '');
                $video = '';
                if (!empty($video_url)) {
                    global $wp_embed;
                    echo esc_html($wp_embed->run_shortcode('[embed]' . $video_url . '[/embed]'));
                } elseif (!empty($video_file)) {
                    if (strpos('[embed', $video_file)) {
                        global $wp_embed;
                        echo esc_html($wp_embed->run_shortcode($video_file));
                    } else {
                        echo do_shortcode($video_file);
                    }
                } else {
                    if ('' != $video_html) {
                        echo esc_html($video_html);
                    }
                }
                ?>
            </div>
        </div>
    <?php elseif (has_post_format('audio')) : ?>
        <div class="entry-featured">
            <?php
                $audio_url = frontline_get_post_format_value('post-audio-url', '#');
                echo esc_url($audio_url);
            ?>
        </div>
    <?php else :
        if (has_post_thumbnail() && $post_feature_image_on == true) {
            echo '<div class="entry-featured"><div class="post-image">'; ?>
                <?php the_post_thumbnail('large'); ?>
            <?php echo '</div></div>';
        } ?>
    <?php endif; ?>
    <div class="entry-holder">
        <div class="post-meta">
            <div class="post-meta-inner">
                <div class="left-meta-inner">
                    <?php if ($post_author_on) : ?>
                        <div class="avatar-info">
                            <?php
                            if (!empty(get_avatar( get_the_author_meta( 'ID' )))){
                                echo get_avatar( get_the_author_meta( 'ID' ), 50 );
                            }else{
                                ?><i class="zmdi zmdi-account"></i> <?php
                            }
                            ?>
                        </div>
                        <div class="name-info">
                            <h5><?php the_author_posts_link(); ?></h5>
                            <p class="desc"><?php the_author_meta( 'description'); ?></p>
                        </div>
                    <?php endif; ?>
                </div>
                <div class="right-meta-inner">
                    <ul class="entry-meta">
                        <?php
                        $countKey = 'post_views_count';
                        $count    = get_post_meta( get_the_ID(), $countKey, true );
                         if ($post_view_on) { ?>
                            <li>
                                <i class="fa fa-eye" aria-hidden="true"></i>
                                <?php echo esc_html($count).' '.esc_html__('Views', 'frontline');?>
                            </li>
                        <?php } ?>
                        <?php if ($post_date_on) { ?>
                            <li>
                                <svg class="svg-icon" width="14" height="14" aria-hidden="true" role="img" focusable="false" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24">
                                    <defs><path id="a" d="M0 0h24v24H0V0z"></path></defs><clipPath id="b"><use xlink:href="#a" overflow="visible"></use></clipPath><path clip-path="url(#b)" d="M12 2C6.5 2 2 6.5 2 12s4.5 10 10 10 10-4.5 10-10S17.5 2 12 2zm4.2 14.2L11 13V7h1.5v5.2l4.5 2.7-.8 1.3z"></path>
                                </svg>
                                <?php echo get_the_date(); ?>
                            </li>
                        <?php } ?>
                        <?php if($post_categories_on && get_the_category()){ ?>
                            <li class="meta-categories">
                                <i class="zmdi zmdi-folder"></i>
                                <?php  the_category(', '); ?>
                            </li>
                        <?php } ?>
                        <?php if ($post_comments_on) : ?>
                            <li>
                                <i class="fa fa-commenting-o" aria-hidden="true"></i>
                                <a href="<?php the_permalink(); ?>"><?php comments_number(esc_html__('0 Comments', 'frontline'), esc_html__('1 Comment', 'frontline'), esc_html__('% Comments', 'frontline')); ?></a>
                            </li>
                        <?php endif; ?>
                    </ul>
                </div>
            </div>
        </div>
    </div>
    <div class="entry-body">
        <div class="entry-content clearfix">
            <?php
                the_content();
                wp_link_pages( array(
                    'before'      => '<div class="page-links">',
                    'after'       => '</div>',
                    'link_before' => '<span>',
                    'link_after'  => '</span>',
                ) );
            ?>
        </div><!-- .entry-content -->
        <?php if($post_tags_on) :
            frontline_entry_tagged_in();
        endif; ?>
        <?php if($post_social_share_on) {
            ?>
            <div class="entry-social">
                <span class="label"><?php echo esc_html__('Share', 'frontline').': '; ?></span>
                <?php frontline_socials_share_default(); ?>
            </div>
            <?php
        } ?>
        <?php frontline_post_nav_default(); ?>
    </div>
</article><!-- #post -->