<?php defined( 'ABSPATH' ) or exit( -1 );
/**
 * Case Study Info widgets
 *
 * @package Frontline
 * @version 1.0
 */

class CMS_Area_Brochures_Widget extends WP_Widget
{
    function __construct()
    {
        parent::__construct(
            'cms_area_brochures',
            esc_html__( '* Practice Area Brochures', 'frontline' ),
            array(
                'description' => __( 'Shows brochures download in practice area single.', 'frontline' ),
            )
        );
    }

    /**
     * Outputs the HTML for this widget.
     *
     * @param array $args An array of standard parameters for widgets in this theme
     * @param array $instance An array of settings for this widget instance
     * @return void Echoes it's output
     **/
    function widget( $args, $instance )
    {
        if (!is_singular('area')){
            return false;
        }
        extract($args);
        $title = isset($instance['title']) ? (!empty($instance['title']) ? $instance['title'] : '') : '';
        $description = isset($instance['description']) ? (!empty($instance['description']) ? $instance['description'] : '') : '';
        $area_download_1 = frontline_get_page_opt('area_download_1');
        $area_download_2 = frontline_get_page_opt('area_download_2');

        ?>
        <div class="cms-area-brochures widget">
            <?php if (!empty($title)) : ?>
                <h2 class="widget-title">
                    <?php
                    if (function_exists('etc_print_html')){
                        etc_print_html(nl2br($title));
                    }else{
                        echo wp_kses_post($title);
                    }
                    ?>
                </h2>
            <?php endif; ?>
            <?php if (!empty($description)): ?>
                <div class="brochures-description">
                    <p><?php echo wp_kses_post($description); ?></p>
                </div>
            <?php endif; ?>

            <div class="info-buttons font-smooth">
                <?php if($area_download_1) : ?>
                    <p><?php echo wp_kses_post($area_download_1); ?></p>
                <?php endif; ?>

                <?php if($area_download_2) : ?>
                    <p><?php echo wp_kses_post($area_download_2); ?></p>
                <?php endif; ?>
            </div>
        </div>
        <?php
    }

    /**
     * Deals with the settings when they are saved by the admin. Here is
     * where any validation should be dealt with.
     *
     * @param array $new_instance An array of new settings as submitted by the admin
     * @param array $old_instance An array of the previous settings
     * @return array The validated and (if necessary) amended settings
     **/
    function update( $new_instance, $old_instance )
    {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['description'] = strip_tags($new_instance['description']);
        return $instance;
    }

    /**
     * Displays the form for this widget on the Widgets page of the WP Admin area.
     *
     * @param array $instance An array of the current settings for this widget
     * @return void Echoes it's output
     **/
    function form( $instance )
    {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $description = isset($instance['description']) ? esc_attr($instance['description']) : '';
        ?>
        <p>
            <label for="<?php echo esc_url($this->get_field_id('title')); ?>"><?php esc_html_e( 'Title', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>

        <p>
            <label for="<?php echo esc_url($this->get_field_id('description')); ?>"><?php esc_html_e('Description', 'frontline'); ?></label>
            <textarea class="widefat" rows="8" cols="20" id="<?php echo esc_attr($this->get_field_id('description')); ?>" name="<?php echo esc_attr($this->get_field_name('description')); ?>"><?php echo wp_kses_post($description); ?></textarea>
        </p>
        <?php
    }
}

function register_area_brochures_widget()
{
    global $wp_widget_factory;
    $wp_widget_factory->register( 'CMS_Area_Brochures_Widget' );
}

add_action('widgets_init', 'register_area_brochures_widget'); ?>