<?php
class CMS_GetInTouch_Widget extends WP_Widget {

    function __construct() {
        parent::__construct(
            'cms_textbox_widget',
            esc_html__('* Get In Touch', 'frontline'),
            array('description' => esc_html__('Get In Touch Widget', 'frontline'),)
        );
    }

    function widget($args, $instance) {

        extract($args);

        $title = isset($instance['title']) ? (!empty($instance['title']) ? $instance['title']: '') : '';
        $phone_label = isset($instance['phone_label']) ? (!empty($instance['phone_label']) ? $instance['phone_label']: '') : '';
        $phone_text = isset($instance['phone_text']) ? (!empty($instance['phone_text']) ? $instance['phone_text']: '') : '';
        $phone_text_href = str_replace(array( ' ','+' ), '', $phone_text);
        $fax_label = isset($instance['fax_label']) ? (!empty($instance['fax_label']) ? $instance['fax_label']: '') : '';
        $fax_text = isset($instance['fax_text']) ? (!empty($instance['fax_text']) ? $instance['fax_text']: '') : '';
        $mail_label = isset($instance['mail_label']) ? (!empty($instance['mail_label']) ? $instance['mail_label']: '') : '';
        $mail_text = isset($instance['mail_text']) ? (!empty($instance['mail_text']) ? $instance['mail_text']: '') : '';
        $address_title = isset($instance['address_title']) ? (!empty($instance['address_title']) ? $instance['address_title']: '') : '';
        $address_text = isset($instance['address_text']) ? (!empty($instance['address_text']) ? $instance['address_text']: '') : '';
        $address_text_url = "http://maps.google.com/?q=".$address_text;
        ?>
        <div class="cms-get-in-touch widget">
            <?php if(!empty($title)) : ?>
                <h2 class="widget-title"><?php echo esc_attr($title); ?></h2>
            <?php endif; ?>
            <div class="cms-contact-info-inner">
                <?php if(!empty($phone_text)): ?>
                    <div class="cms-contact-info-item type-phone">
                        <div class="cms-contact-info-holder">
                            <?php if (!empty($phone_label)){
                                ?><span><?php echo esc_attr( $phone_label  ); ?></span><?php
                            }?>
                            <a href="tel:<?php echo esc_attr( $phone_text_href ); ?>"><?php echo wp_kses_post( $phone_text  ); ?></a>
                        </div>
                    </div>
                <?php endif; ?>
                <?php if(!empty($fax_text)): ?>
                    <div class="cms-contact-info-item type-fax">
                        <div class="cms-contact-info-holder">
                            <?php if (!empty($fax_label)){
                                ?><span><?php echo esc_attr( $fax_label  ); ?></span><?php
                            }?>
                            <span>
                                <?php echo wp_kses_post( $fax_text  ); ?>
                            </span>
                        </div>
                    </div>
                <?php endif; ?>
                <?php if(!empty($mail_text)): ?>
                    <div class="cms-contact-info-item type-email">
                        <div class="cms-contact-info-holder">
                            <?php if (!empty($mail_label)){
                                ?><span><?php echo esc_attr( $mail_label  ); ?></span><?php
                            }?>
                            <a href="mailto:<?php echo esc_attr( $mail_text ); ?>">
                                <?php echo wp_kses_post( $mail_text  ); ?>
                            </a>
                        </div>
                    </div>
                <?php endif; ?>
            </div>
            <div class="cms-contact-info-inner">
                <?php if(!empty($address_text)): ?>
                    <div class="cms-contact-info-item type-address">
                        <div class="cms-contact-info-holder">
                            <?php if (!empty($address_title)){
                                ?><h4><?php echo esc_attr( $address_title  ); ?></h4><?php
                            }?>
                            <a href="<?php echo esc_url($address_text_url); ?>" target="_blank">
                                <?php echo wp_kses_post( $address_text  ); ?>
                            </a>
                        </div>
                    </div>
                <?php endif; ?>
            </div>
            <div class="cms-contact-info-inner">
                <?php if(!empty($address_text)): ?>
                    <div class="cms-contact-info-item type-address">
                        <div class="cms-contact-info-holder">
                            <div class="cms-social-media">
                                <?php frontline_social_media(); ?>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>
            </div>
        </div>
        <?php
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['phone_label'] = strip_tags($new_instance['phone_label']);
        $instance['phone_text'] = strip_tags($new_instance['phone_text']);
        $instance['fax_label'] = strip_tags($new_instance['fax_label']);
        $instance['fax_text'] = strip_tags($new_instance['fax_text']);
        $instance['mail_label'] = strip_tags($new_instance['mail_label']);
        $instance['mail_text'] = strip_tags($new_instance['mail_text']);
        $instance['address_title'] = strip_tags($new_instance['address_title']);
        $instance['address_text'] = strip_tags($new_instance['address_text']);

        return $instance;
    }

    function form( $instance ) {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $phone_label = isset($instance['phone_label']) ? esc_attr($instance['phone_label']) : '';
        $phone_text = isset($instance['phone_text']) ? esc_attr($instance['phone_text']) : '';
        $fax_label = isset($instance['fax_label']) ? esc_attr($instance['fax_label']) : '';
        $fax_text = isset($instance['fax_text']) ? esc_attr($instance['fax_text']) : '';
        $mail_label = isset($instance['mail_label']) ? esc_attr($instance['mail_label']) : '';
        $mail_text = isset($instance['mail_text']) ? esc_attr($instance['mail_text']) : '';
        $address_title = isset($instance['address_title']) ? esc_attr($instance['address_title']) : '';
        $address_text = isset($instance['address_text']) ? esc_attr($instance['address_text']) : '';

        ?>
        <p><label for="<?php echo esc_url($this->get_field_id('title')); ?>"><?php esc_html_e( 'Title', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>

        <p><label for="<?php echo esc_url($this->get_field_id('phone_label')); ?>"><?php esc_html_e( 'Phone Label', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('phone_label') ); ?>" name="<?php echo esc_attr( $this->get_field_name('phone_label') ); ?>" type="text" value="<?php echo esc_attr( $phone_label ); ?>" /></p>

        <p><label for="<?php echo esc_url($this->get_field_id('phone_text')); ?>"><?php esc_html_e( 'Phone Text', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('phone_text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('phone_text') ); ?>" type="text" value="<?php echo esc_attr( $phone_text ); ?>" /></p>

        <p><label for="<?php echo esc_url($this->get_field_id('fax_label')); ?>"><?php esc_html_e( 'Fax Label', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('fax_label') ); ?>" name="<?php echo esc_attr( $this->get_field_name('fax_label') ); ?>" type="text" value="<?php echo esc_attr( $fax_label ); ?>" /></p>

        <p><label for="<?php echo esc_url($this->get_field_id('fax_text')); ?>"><?php esc_html_e( 'Fax Text', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('fax_text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('fax_text') ); ?>" type="text" value="<?php echo esc_attr( $fax_text ); ?>" /></p>
        
        <p><label for="<?php echo esc_url($this->get_field_id('mail_label')); ?>"><?php esc_html_e( 'Mail Label', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('mail_label') ); ?>" name="<?php echo esc_attr( $this->get_field_name('mail_label') ); ?>" type="text" value="<?php echo esc_attr( $mail_label ); ?>" /></p>

        <p><label for="<?php echo esc_url($this->get_field_id('mail_text')); ?>"><?php esc_html_e( 'Mail Text', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('mail_text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('mail_text') ); ?>" type="text" value="<?php echo esc_attr( $mail_text ); ?>" /></p>

        <p><label for="<?php echo esc_url($this->get_field_id('address_title')); ?>"><?php esc_html_e( 'Address Title', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('address_title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('address_title') ); ?>" type="text" value="<?php echo esc_attr( $address_title ); ?>" /></p>

        <p><label for="<?php echo esc_url($this->get_field_id('address_text')); ?>"><?php esc_html_e( 'Address Text', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('address_text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('address_text') ); ?>" type="text" value="<?php echo esc_attr( $address_text ); ?>" /></p>
        <?php
    }

}

function register_getintouch_widget() {
    global $wp_widget_factory;
    $wp_widget_factory->register( 'CMS_GetInTouch_Widget' );
}
add_action('widgets_init', 'register_getintouch_widget'); ?>